"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[147],{17437:function(t,r,n){n.d(r,{$OI:function(){return i},Pkc:function(){return o}});var e=n(25281);function o(t){return(0,e.w_)({tag:"svg",attr:{viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round"},child:[{tag:"path",attr:{d:"M3 3v18h18"}},{tag:"rect",attr:{width:"12",height:"4",x:"7",y:"5",rx:"1"}},{tag:"rect",attr:{width:"7",height:"4",x:"7",y:"13",rx:"1"}}]})(t)}function i(t){return(0,e.w_)({tag:"svg",attr:{viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round"},child:[{tag:"path",attr:{d:"M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6"}},{tag:"polyline",attr:{points:"15 3 21 3 21 9"}},{tag:"line",attr:{x1:"10",x2:"21",y1:"14",y2:"3"}}]})(t)}}}]);