@layer rdg.MeasuringCell{.mlln6zg7-0-0-beta-40{contain:strict;grid-row:1;visibility:hidden}}@layer rdg.Cell{.cj343x07-0-0-beta-40{position:relative;padding-block:0;padding-inline:8px;border-inline-end:1px solid var(--rdg-border-color);border-block-end:1px solid var(--rdg-border-color);grid-row-start:var(--rdg-grid-row-start);background-color:inherit;white-space:nowrap;overflow:clip;text-overflow:ellipsis;outline:none}.cj343x07-0-0-beta-40[aria-selected=true]{outline:2px solid var(--rdg-selection-color);outline-offset:-2px}.csofj7r7-0-0-beta-40{position:sticky;z-index:1}.ch2wcw87-0-0-beta-40{box-shadow:calc(2px * var(--rdg-sign)) 0 5px -2px hsla(0,0%,53%,.3)}}@layer rdg.CheckboxLabel{.c1bn88vv7-0-0-beta-40{cursor:pointer;display:flex;align-items:center;justify-content:center;position:absolute;inset:0;margin-inline-end:1px}}@layer rdg.CheckboxInput{.c1qt073l7-0-0-beta-40{all:unset}}@layer rdg.CheckboxIcon{.cf71kmq7-0-0-beta-40{content:"";inline-size:20px;block-size:20px;border:2px solid var(--rdg-border-color);background-color:var(--rdg-background-color)}.c1qt073l7-0-0-beta-40:checked+.cf71kmq7-0-0-beta-40{background-color:var(--rdg-checkbox-color);outline:4px solid var(--rdg-background-color);outline-offset:-6px}.c1qt073l7-0-0-beta-40:focus+.cf71kmq7-0-0-beta-40{border-color:var(--rdg-checkbox-focus-color)}}@layer rdg.CheckboxLabel{.c1lwve4p7-0-0-beta-40{cursor:default}.c1lwve4p7-0-0-beta-40 .cf71kmq7-0-0-beta-40{border-color:var(--rdg-checkbox-disabled-border-color);background-color:var(--rdg-checkbox-disabled-background-color)}}@layer rdg.GroupCellContent{.g1s9ylgp7-0-0-beta-40{outline:none}}@layer rdg.GroupCellCaret{.cz54e4y7-0-0-beta-40{margin-inline-start:4px;stroke:currentColor;stroke-width:1.5px;fill:transparent;vertical-align:middle}.cz54e4y7-0-0-beta-40>path{transition:d .1s}}@layer rdg.DragHandle{.c1w9bbhr7-0-0-beta-40{--rdg-drag-handle-size:8px;z-index:0;cursor:move;inline-size:var(--rdg-drag-handle-size);block-size:var(--rdg-drag-handle-size);background-color:var(--rdg-selection-color);place-self:end}.c1w9bbhr7-0-0-beta-40:hover{--rdg-drag-handle-size:16px;border:2px solid var(--rdg-selection-color);background-color:var(--rdg-background-color)}.c1creorc7-0-0-beta-40{z-index:1;position:sticky}}@layer rdg.EditCell{.cis5rrm7-0-0-beta-40{padding:0}}@layer rdg.SortableHeaderCell{.h44jtk67-0-0-beta-40{display:flex}}@layer rdg.SortableHeaderCellName{.hcgkhxz7-0-0-beta-40{flex-grow:1;overflow:clip;text-overflow:ellipsis}}@layer rdg.HeaderCell{.c6l2wv17-0-0-beta-40{cursor:pointer}.c1kqdw7y7-0-0-beta-40{touch-action:none}.r1y6ywlx7-0-0-beta-40{cursor:col-resize;position:absolute;inset-block-start:0;inset-inline-end:0;inset-block-end:0;inline-size:10px}}.c1bezg5o7-0-0-beta-40{opacity:.5}.c1vc96037-0-0-beta-40{background-color:var(--rdg-header-draggable-background-color)}@layer rdg.Row{.r1upfr807-0-0-beta-40{display:contents;line-height:var(--rdg-row-height);background-color:var(--rdg-background-color)}.r1upfr807-0-0-beta-40:hover{background-color:var(--rdg-row-hover-background-color)}.r1upfr807-0-0-beta-40[aria-selected=true]{background-color:var(--rdg-row-selected-background-color)}.r1upfr807-0-0-beta-40[aria-selected=true]:hover{background-color:var(--rdg-row-selected-hover-background-color)}}@layer rdg.FocusSink{.r190mhd37-0-0-beta-40{outline:2px solid var(--rdg-selection-color);outline-offset:-2px}.r139qu9m7-0-0-beta-40:before{content:"";display:inline-block;height:100%;position:sticky;inset-inline-start:0;border-inline-start:2px solid var(--rdg-selection-color)}}@layer rdg.HeaderRow{.h10tskcx7-0-0-beta-40{display:contents;line-height:var(--rdg-header-row-height);background-color:var(--rdg-header-background-color);font-weight:700}.h10tskcx7-0-0-beta-40>.cj343x07-0-0-beta-40{z-index:2;position:sticky}.h10tskcx7-0-0-beta-40>.csofj7r7-0-0-beta-40{z-index:3}}@layer rdg.Cell{.c6ra8a37-0-0-beta-40,.cq910m07-0-0-beta-40{background-color:#ccf}.cq910m07-0-0-beta-40.c6ra8a37-0-0-beta-40{background-color:#99f}}@layer rdg.SortIcon{.a3ejtar7-0-0-beta-40{fill:currentColor}.a3ejtar7-0-0-beta-40>path{transition:d .1s}}@layer rdg{@layer Defaults,
      FocusSink,
      CheckboxInput,
      CheckboxIcon,
      CheckboxLabel,
      Cell,
      HeaderCell,
      SummaryCell,
      EditCell,
      Row,
      HeaderRow,
      SummaryRow,
      GroupedRow,
      Root;@layer Defaults{.rnvodz57-0-0-beta-40 *,.rnvodz57-0-0-beta-40 :after,.rnvodz57-0-0-beta-40 :before{box-sizing:inherit}}@layer Root{.rnvodz57-0-0-beta-40{--rdg-color:#000;--rdg-border-color:#ddd;--rdg-summary-border-color:#aaa;--rdg-background-color:#fff;--rdg-header-background-color:#f9f9f9;--rdg-header-draggable-background-color:#e7e7e7;--rdg-row-hover-background-color:#f5f5f5;--rdg-row-selected-background-color:#dbecfa;--rdg-row-selected-hover-background-color:#c9e3f8;--rdg-checkbox-color:#005194;--rdg-checkbox-focus-color:#61b8ff;--rdg-checkbox-disabled-border-color:#ccc;--rdg-checkbox-disabled-background-color:#ddd;--rdg-selection-color:#66afe9;--rdg-font-size:14px;display:grid;color-scheme:var(--rdg-color-scheme,light dark);contain:content;content-visibility:auto;block-size:350px;border:1px solid var(--rdg-border-color);box-sizing:border-box;overflow:auto;background-color:var(--rdg-background-color);color:var(--rdg-color);font-size:var(--rdg-font-size)}.rnvodz57-0-0-beta-40:before{content:"";grid-column:1/-1;grid-row:1/-1}.rnvodz57-0-0-beta-40.rdg-dark{--rdg-color-scheme:dark;--rdg-color:#ddd;--rdg-border-color:#444;--rdg-summary-border-color:#555;--rdg-background-color:#212121;--rdg-header-background-color:#1b1b1b;--rdg-header-draggable-background-color:#2d2d2d;--rdg-row-hover-background-color:#171717;--rdg-row-selected-background-color:#1a73bc;--rdg-row-selected-hover-background-color:#1768ab;--rdg-checkbox-color:#94cfff;--rdg-checkbox-focus-color:#c7e6ff;--rdg-checkbox-disabled-border-color:#000;--rdg-checkbox-disabled-background-color:#333}.rnvodz57-0-0-beta-40.rdg-light{--rdg-color-scheme:light}@media (prefers-color-scheme:dark){.rnvodz57-0-0-beta-40:not(.rdg-light){--rdg-color:#ddd;--rdg-border-color:#444;--rdg-summary-border-color:#555;--rdg-background-color:#212121;--rdg-header-background-color:#1b1b1b;--rdg-header-draggable-background-color:#2d2d2d;--rdg-row-hover-background-color:#171717;--rdg-row-selected-background-color:#1a73bc;--rdg-row-selected-hover-background-color:#1768ab;--rdg-checkbox-color:#94cfff;--rdg-checkbox-focus-color:#c7e6ff;--rdg-checkbox-disabled-border-color:#000;--rdg-checkbox-disabled-background-color:#333}}}}@layer rdg.Root{.vlqv91k7-0-0-beta-40{-webkit-user-select:none;-moz-user-select:none;user-select:none}.vlqv91k7-0-0-beta-40 .r1upfr807-0-0-beta-40{cursor:move}}@layer rdg.FocusSink{.f1lsfrzw7-0-0-beta-40{grid-column:1/-1;pointer-events:none;z-index:1}.f1cte0lg7-0-0-beta-40{z-index:3}}@layer rdg.SummaryCell{.s8wc6fl7-0-0-beta-40{inset-block-start:var(--rdg-summary-row-top);inset-block-end:var(--rdg-summary-row-bottom)}}@layer rdg.SummaryRow{.skuhp557-0-0-beta-40{line-height:var(--rdg-summary-row-height)}.skuhp557-0-0-beta-40>.cj343x07-0-0-beta-40{position:sticky}.tf8l5ub7-0-0-beta-40>.cj343x07-0-0-beta-40{z-index:2}.tf8l5ub7-0-0-beta-40>.csofj7r7-0-0-beta-40{z-index:3}.tb9ughf7-0-0-beta-40>.cj343x07-0-0-beta-40{border-block-end:2px solid var(--rdg-summary-border-color)}.b1yssfnt7-0-0-beta-40>.cj343x07-0-0-beta-40{border-block-start:2px solid var(--rdg-summary-border-color)}}@layer rdg.GroupedRow{.g1yxluv37-0-0-beta-40:not([aria-selected=true]){background-color:var(--rdg-header-background-color)}.g1yxluv37-0-0-beta-40>.cj343x07-0-0-beta-40:not(:last-child):not(.ch2wcw87-0-0-beta-40){border-inline-end:none}}@layer rdg.TextEditor{.t7vyx3i7-0-0-beta-40{-webkit-appearance:none;-moz-appearance:none;appearance:none;box-sizing:border-box;inline-size:100%;block-size:100%;padding-block:0;padding-inline:6px;border:2px solid #ccc;vertical-align:top;color:var(--rdg-color);background-color:var(--rdg-background-color);font-family:inherit;font-size:var(--rdg-font-size)}.t7vyx3i7-0-0-beta-40:focus{border-color:var(--rdg-selection-color);outline:none}.t7vyx3i7-0-0-beta-40::-moz-placeholder{color:#999;opacity:1}.t7vyx3i7-0-0-beta-40::placeholder{color:#999;opacity:1}}.index-column{color:grey;text-align:right}.diff-header-added{background-color:#3aa53a;color:#fff}.diff-cell-added{background-color:#cefece;color:#000}.diff-header-removed{background-color:#f66;color:#fff}.diff-cell-modified,.diff-cell-removed{background-color:#ffc5c5;color:#000}.cell-show-context-menu{overflow:visible}.grid-header:hover .key-icon,.grid-header:hover .pin-icon{display:block}.rdg-cell{border-width:0 1px 1px 0;border-style:solid;border-color:var(--rdg-border-color)}.rdg-row:hover .row-context-menu{visibility:visible;width:auto}